Index: tests/corelib/linked_hash_map_from_iterable_test.dart |
diff --git a/tests/corelib/map_from_iterable_test.dart b/tests/corelib/linked_hash_map_from_iterable_test.dart |
similarity index 64% |
copy from tests/corelib/map_from_iterable_test.dart |
copy to tests/corelib/linked_hash_map_from_iterable_test.dart |
index 4d0468db66a48f55f4dbe162491cb47d5b90355b..d581532612911d3d1c289fc50704855dcb2adb16 100644 |
--- a/tests/corelib/map_from_iterable_test.dart |
+++ b/tests/corelib/linked_hash_map_from_iterable_test.dart |
@@ -16,10 +16,11 @@ main() { |
} |
void defaultFunctionValuesTest() { |
- var map = new Map.fromIterable([1, 2, 3]); |
+ var map = new LinkedHashMap.fromIterable([1, 2, 3]); |
Expect.isTrue(map is Map); |
- Expect.isTrue(map is HashMap); |
+ Expect.isTrue(map is LinkedHashMap); |
+ Expect.isFalse(map is HashMap); |
Expect.equals(3, map.length); |
Expect.equals(3, map.keys.length); |
@@ -31,10 +32,11 @@ void defaultFunctionValuesTest() { |
} |
void defaultKeyFunctionTest() { |
- var map = new Map.fromIterable([1, 2, 3], value: (x) => x + 1); |
+ var map = new LinkedHashMap.fromIterable([1, 2, 3], value: (x) => x + 1); |
Expect.isTrue(map is Map); |
- Expect.isTrue(map is HashMap); |
+ Expect.isTrue(map is LinkedHashMap); |
+ Expect.isFalse(map is HashMap); |
Expect.equals(3, map.length); |
Expect.equals(3, map.keys.length); |
@@ -46,10 +48,11 @@ void defaultKeyFunctionTest() { |
} |
void defaultValueFunctionTest() { |
- var map = new Map.fromIterable([1, 2, 3], key: (x) => x + 1); |
+ var map = new LinkedHashMap.fromIterable([1, 2, 3], key: (x) => x + 1); |
Expect.isTrue(map is Map); |
- Expect.isTrue(map is HashMap); |
+ Expect.isTrue(map is LinkedHashMap); |
+ Expect.isFalse(map is HashMap); |
Expect.equals(3, map.length); |
Expect.equals(3, map.keys.length); |
@@ -61,12 +64,12 @@ void defaultValueFunctionTest() { |
} |
void noDefaultValuesTest() { |
- var map = new Map.fromIterable([1, 2, 3], |
+ var map = new LinkedHashMap.fromIterable([1, 2, 3], |
key: (x) => x + 1, value: (x) => x - 1); |
- |
Expect.isTrue(map is Map); |
- Expect.isTrue(map is HashMap); |
+ Expect.isTrue(map is LinkedHashMap); |
+ Expect.isFalse(map is HashMap); |
Expect.equals(3, map.length); |
Expect.equals(3, map.keys.length); |
@@ -78,9 +81,10 @@ void noDefaultValuesTest() { |
} |
void emptyIterableTest() { |
- var map = new Map.fromIterable([]); |
+ var map = new LinkedHashMap.fromIterable([]); |
Expect.isTrue(map is Map); |
- Expect.isTrue(map is HashMap); |
+ Expect.isTrue(map is LinkedHashMap); |
+ Expect.isFalse(map is HashMap); |
Expect.equals(0, map.length); |
Expect.equals(0, map.keys.length); |
@@ -88,10 +92,11 @@ void emptyIterableTest() { |
} |
void equalElementsTest() { |
- var map = new Map.fromIterable([1, 2, 2], key: (x) => x + 1); |
+ var map = new LinkedHashMap.fromIterable([1, 2, 2], key: (x) => x + 1); |
Expect.isTrue(map is Map); |
- Expect.isTrue(map is HashMap); |
+ Expect.isTrue(map is LinkedHashMap); |
+ Expect.isFalse(map is HashMap); |
Expect.equals(2, map.length); |
Expect.equals(2, map.keys.length); |
@@ -102,11 +107,12 @@ void equalElementsTest() { |
} |
void genericTypeTest() { |
- var map = new Map<int, String>.fromIterable([1, 2, 3], value: (x) => '$x'); |
+ var map = new LinkedHashMap<int, String>.fromIterable([1, 2, 3], value: (x) => '$x'); |
Expect.isTrue(map is Map<int, String>); |
+ Expect.isTrue(map is LinkedHashMap<int, String>); |
- // Make sure it is not just Map<dynamic, dynamic>. |
- Expect.isFalse(map is Map<String, dynamic>); |
- Expect.isFalse(map is Map<dynamic, int>); |
+ // Make sure it is not just LinkedHashMap<dynamic, dynamic>. |
+ Expect.isFalse(map is LinkedHashMap<String, dynamic>); |
+ Expect.isFalse(map is LinkedHashMap<dynamic, int>); |
} |